@@ -24,7 +24,7 @@
 #include "output.h"
 #include "screen.h"
 #include "edid.h"
-#include "debug_p.h"
+#include "kscreen_debug.h"
 
 #include <QDBusArgument>
 #include <QJsonDocument>
@@ -86,6 +86,7 @@ QJsonObject ConfigSerializer::serializeOutput(const OutputPtr &output)
     obj[QLatin1String("currentModeId")] = output->currentModeId();
     obj[QLatin1String("preferredModes")] = serializeList(output->preferredModes());
     obj[QLatin1String("connected")] = output->isConnected();
+    obj[QLatin1String("followPreferredMode")] = output->followPreferredMode();
     obj[QLatin1String("enabled")] = output->isEnabled();
     obj[QLatin1String("primary")] = output->isPrimary();
     obj[QLatin1String("clones")] = serializeList(output->clones());
@@ -177,12 +178,12 @@ ConfigPtr ConfigSerializer::deserializeConfig(const QVariantMap &map)
 {
     ConfigPtr config(new Config);
 
-    if (map.contains(QLatin1String("features"))) {
-        config->setSupportedFeatures(static_cast<Config::Features>(map[QLatin1String("features")].toInt()));
+    if (map.contains(QStringLiteral("features"))) {
+        config->setSupportedFeatures(static_cast<Config::Features>(map[QStringLiteral("features")].toInt()));
     }
 
-    if (map.contains(QLatin1String("outputs"))) {
-        const QDBusArgument &outputsArg = map[QLatin1String("outputs")].value<QDBusArgument>();
+    if (map.contains(QStringLiteral("outputs"))) {
+        const QDBusArgument &outputsArg = map[QStringLiteral("outputs")].value<QDBusArgument>();
         outputsArg.beginArray();
         OutputList outputs;
         while (!outputsArg.atEnd()) {
@@ -198,8 +199,8 @@ ConfigPtr ConfigSerializer::deserializeConfig(const QVariantMap &map)
         config->setOutputs(outputs);
     }
 
-    if (map.contains(QLatin1String("screen"))) {
-        const QDBusArgument &screenArg = map[QLatin1String("screen")].value<QDBusArgument>();
+    if (map.contains(QStringLiteral("screen"))) {
+        const QDBusArgument &screenArg = map[QStringLiteral("screen")].value<QDBusArgument>();
         const KScreen::ScreenPtr screen = deserializeScreen(screenArg);
         if (!screen) {
             return ConfigPtr();
@@ -242,6 +243,8 @@ OutputPtr ConfigSerializer::deserializeOutput(const QDBusArgument &arg)
             output->setPreferredModes(deserializeList<QString>(value.value<QDBusArgument>()));
         } else if (key == QLatin1String("connected")) {
             output->setConnected(value.toBool());
+        } else if (key == QLatin1String("followPreferredMode")) {
+            output->setFollowPreferredMode(value.toBool());
         } else if (key == QLatin1String("enabled")) {
             output->setEnabled(value.toBool());
         } else if (key == QLatin1String("primary")) {
