@@ -22,10 +22,10 @@
 #include "edid.h"
 #include "abstractbackend.h"
 #include "backendmanager_p.h"
-#include "debug_p.h"
+#include "kscreen_debug.h"
 
 #include <QStringList>
-#include <QPointer>
+#include <QScopedPointer>
 #include <QRect>
 
 using namespace KScreen;
@@ -60,13 +60,14 @@ class Q_DECL_HIDDEN Output::Private
         scale(other.scale),
         connected(other.connected),
         enabled(other.enabled),
-        primary(other.primary)
+        primary(other.primary),
+        followPreferredMode(other.followPreferredMode)
     {
         Q_FOREACH (const ModePtr &otherMode, other.modeList) {
             modeList.insert(otherMode->id(), otherMode->clone());
         }
         if (other.edid) {
-            edid = other.edid->clone();
+            edid.reset(other.edid->clone());
         }
     }
 
@@ -90,18 +91,24 @@ class Q_DECL_HIDDEN Output::Private
     bool connected;
     bool enabled;
     bool primary;
+    bool followPreferredMode = false;
 
-    mutable QPointer<Edid> edid;
+    QScopedPointer<Edid> edid;
 };
 
 bool Output::Private::compareModeList(const ModeList& before, const ModeList &after)
 {
-    if (before.keys() != after.keys()) {
+    if (before.count() != after.count()) {
         return false;
     }
-    for (const QString &key : before.keys()) {
-        const auto mb = before.value(key);
-        const auto ma = after.value(key);
+
+    for (auto itb = before.constBegin(); itb != before.constEnd(); ++itb) {
+        auto ita = after.constFind(itb.key());
+        if (ita == after.constEnd()) {
+            return false;
+        }
+        const auto &mb = itb.value();
+        const auto &ma = ita.value();
         if (mb->id() != ma->id()) {
             return false;
         }
@@ -203,6 +210,14 @@ void Output::setName(const QString& name)
     Q_EMIT outputChanged();
 }
 
+QString Output::hash() const
+{
+    if (edid() && edid()->isValid()) {
+        return edid()->hash();
+    }
+    return name();
+}
+
 Output::Type Output::type() const
 {
     return d->type;
@@ -447,7 +462,7 @@ QList<int> Output::clones() const
     return d->clones;
 }
 
-void Output::setClones(QList<int> outputlist)
+void Output::setClones(const QList<int> &outputlist)
 {
     if (d->clones == outputlist) {
         return;
@@ -461,12 +476,12 @@ void Output::setClones(QList<int> outputlist)
 void Output::setEdid(const QByteArray& rawData)
 {
     Q_ASSERT(d->edid.isNull());
-    d->edid = new Edid(rawData);
+    d->edid.reset(new Edid(rawData));
 }
 
 Edid *Output::edid() const
 {
-    return d->edid;
+    return d->edid.data();
 }
 
 QSize Output::sizeMm() const
@@ -479,6 +494,19 @@ void Output::setSizeMm(const QSize &size)
     d->sizeMm = size;
 }
 
+bool KScreen::Output::followPreferredMode() const
+{
+    return d->followPreferredMode;
+}
+
+void KScreen::Output::setFollowPreferredMode(bool follow)
+{
+    if (follow != d->followPreferredMode) {
+        d->followPreferredMode = follow;
+        Q_EMIT followPreferredModeChanged(follow);
+    }
+}
+
 QRect Output::geometry() const
 {
     if (!currentMode()) {
@@ -565,8 +593,7 @@ void Output::apply(const OutputPtr& other)
 
     // Non-notifyable changes
     if (other->d->edid) {
-        delete d->edid;
-        d->edid = other->d->edid->clone();
+        d->edid.reset(other->d->edid->clone());
     }
 
     blockSignals(keepBlocked);
@@ -589,6 +616,7 @@ QDebug operator<<(QDebug dbg, const KScreen::OutputPtr &output)
                                   << "pos:" << output->pos() << "res:" << output->size()
                                   << "modeId:" << output->currentModeId()
                                   << "scale:" << output->scale()
+                                  << "followPreferredMode:" << output->followPreferredMode()
                                   << ")";
     } else {
         dbg << "KScreen::Output(NULL)";
