@@ -35,8 +35,8 @@ class TestPnp : public QObject
     Q_OBJECT
 
 public:
-    explicit TestPnp(bool monitor, QObject *parent = 0);
-    virtual ~TestPnp();
+    explicit TestPnp(bool monitor, QObject *parent = nullptr);
+    ~TestPnp() override;
 
 private Q_SLOTS:
     void init();
